@@ -224,7 +224,6 @@ class Postgres(Dialect):
             "CHARACTER VARYING": TokenType.VARCHAR,
             "DECLARE": TokenType.COMMAND,
             "DO": TokenType.COMMAND,
-            "GRANT": TokenType.COMMAND,
             "HSTORE": TokenType.HSTORE,
             "JSONB": TokenType.JSONB,
             "REFRESH": TokenType.COMMAND,
@@ -259,10 +258,7 @@ class Postgres(Dialect):
             TokenType.HASH: exp.BitwiseXor,
         }
 
-        FACTOR = {
-            **parser.Parser.FACTOR,  # type: ignore
-            TokenType.CARET: exp.Pow,
-        }
+        FACTOR = {**parser.Parser.FACTOR, TokenType.CARET: exp.Pow}
 
     class Generator(generator.Generator):
         LOCKING_READS_SUPPORTED = True
